#
# spec file for package qupzilla
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015 Mariusz Fik <fisiu@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           qupzilla
Version:        2.0.1
Release:        2.2
Summary:        Cross-platform Qt web browser
License:        GPL-3.0+
Group:          Productivity/Networking/Web/Browsers
Url:            http://qupzilla.com/
Source:         https://github.com/QupZilla/%{name}/releases/download/v%{version}/QupZilla-%{version}.tar.xz
Source1:        %{name}.changes
# Search engine favicons.
Source2:        obs.png
Source3:        opensusesoftware.png
# DB shipping openSUSE project bookmark icon.
Source4:        browsedata.db
# PATCH-FEATURE-OPENSUSE qupzilla-defaults.patch
Patch0:         %{name}-defaults.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  kwallet-devel
BuildRequires:  libQt5Gui-private-headers-devel >= 5.6
BuildRequires:  libqt5-qttools-devel >= 5.6
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.6
BuildRequires:  pkgconfig(Qt5Core) >= 5.6
BuildRequires:  pkgconfig(Qt5DBus) >= 5.6
BuildRequires:  pkgconfig(Qt5Gui) >= 5.6
BuildRequires:  pkgconfig(Qt5Network) >= 5.6
BuildRequires:  pkgconfig(Qt5PrintSupport) >= 5.6
BuildRequires:  pkgconfig(Qt5Script) >= 5.6
BuildRequires:  pkgconfig(Qt5Sql) >= 5.6
BuildRequires:  pkgconfig(Qt5WebEngineCore) >= 5.6
BuildRequires:  pkgconfig(Qt5WebEngineWidgets) >= 5.6
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.6
BuildRequires:  pkgconfig(Qt5X11Extras) >= 5.6
BuildRequires:  pkgconfig(gnome-keyring-1)
BuildRequires:  pkgconfig(hunspell)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(xcb-atom)
# qupzilla-qt5 was last seen in openSUSE Leap 42.1.
Provides:       %{name}-qt5 = %{version}
Obsoletes:      %{name}-qt5 < %{version}

%description
QupZilla is a modern web browser based on Qt Framework.

%package gnome-keyring
Summary:        GNOME keyring plugin for QupZilla
Group:          Productivity/Networking/Web/Browsers
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:gnome-keyring)
# qupzilla-qt5-gnome-keyring was last seen in openSUSE Leap 42.1.
Provides:       %{name}-qt5-gnome-keyring = %{version}
Obsoletes:      %{name}-qt5-gnome-keyring < %{version}

%description gnome-keyring
Plugin for QupZilla browser that allows to store passwords in
GNOME Keyring.

%package kwallet
Summary:        Kwallet plugin for QupZilla
Group:          Productivity/Networking/Web/Browsers
Requires:       %{name} = %{version}
Requires:       kwalletd5
Supplements:    packageand(%{name}:plasma5-workspace)
# qupzilla-qt5-kwallet was last seen in openSUSE Leap 42.1.
Provides:       %{name}-qt5-kwallet = %{version}
Obsoletes:      %{name}-qt5-kwallet < %{version}

%description kwallet
Plugin for QupZilla browser that allows to store passwords in
KWallet.

%prep
%setup -q -n QupZilla-%{version}
# Remove __DATE__ and __TIME__.
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
find .  -type f -regex '.*\.\(h\|c\|cpp\)' | xargs sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g"

# QupZilla defaults.
%patch0 -p1
# openSUSE icons.
cp -f %{SOURCE2} %{SOURCE3} src/lib/data/icons/sites/
cp -f %{SOURCE4} src/lib/data/data/

%build
export USE_WEBGL=true
# Enable GNOME Keyring support.
export GNOME_INTEGRATION=true
# Enable better KDE integration, it is also needed for KWallet plugin.
export KDE_INTEGRATION=true
# Set proper LIBPATH.
export USE_LIBPATH=%{_libdir}
%qmake5 \
  CONFIG-=gdb_dwarf_index
make %{?_smp_mflags}

%install
%qmake5_install

# FIXME: Split library into a separate package and also create qupzilla-devel with libqupzilla.so ???
rm -vf %{buildroot}%{_libdir}/libQupZilla.so
# We don't need a test plugin that does nothing.
rm -vf %{buildroot}%{_libdir}/%{name}/libTestPlugin.so

%suse_update_desktop_file %{name}
%fdupes %{buildroot}%{_datadir}/

%post
%desktop_database_post
%icon_theme_cache_post
/sbin/ldconfig

%postun
%desktop_database_postun
%icon_theme_cache_postun
/sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS CHANGELOG COPYRIGHT FAQ GPLv3
%{_bindir}/%{name}
%{_libdir}/libQupZilla.so.*
%{_libdir}/%{name}/
%exclude %{_libdir}/%{name}/libKWalletPasswords.so
%exclude %{_libdir}/%{name}/libGnomeKeyringPasswords.so
%{_datadir}/%{name}/
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/bash-completion/

%files gnome-keyring
%defattr(-,root,root)
%{_libdir}/%{name}/libGnomeKeyringPasswords.so

%files kwallet
%defattr(-,root,root)
%{_libdir}/%{name}/libKWalletPasswords.so

%changelog
* Thu Jun  9 2016 sor.alexei@meowr.ru
- Update to version 2.0.1:
  * Don't force enabling HighDPI scaling by default.
  * Fix crash when unloading AutoScroll plugin.
  * Fix showing Inspect Element action when web inspector is
    disabled.
  * Fix showing context menu when page zoom is not 100%%.
  * Fix destroying WebPage when opened as popup.
  * Fix setting default font families.
  * Fix saving last download path in download manager.
  * Fix using external download manager.
  * Fix canceling http and proxy authentication dialogs.
* Wed Mar 30 2016 sor.alexei@meowr.ru
- Update to version 2.0.0:
  * Switch to QtWebEngine: much better compatibility and stability.
  * Some features from older versions are missing (will come back
    later).
- Rebase qupzilla-defaults.patch.
* Sun Nov 15 2015 javier@opensuse.org
- Update to 1.8.9
  * new QupZilla logo
  * add button to open spellcheck settings in preferences
  * remove gradient in toolbar of browsing library
  * fix showing authors page in about dialog
  * fix showing current tab in tabbar after restoring session
  * fix searching for invalid one-word url strings from locationbar
  * fix switch to tab from locationbar completer when it is the
    only tab in window
* Mon Nov  2 2015 tittiatcoke@gmail.com
- Fix source url to the right location
* Sat Oct 31 2015 sor.alexei@meowr.ru
- Update to 1.8.8:
  * Add interface for extensions to show action in Tools menu.
  * Add option to use TabManager as main tabbar replacement.
  * Fix build with Qt 5.5.1.
  * Fix crash when unloading plugin with visible sidebar.
  * Fix possible crash when accessing last active window.
  * Fix sometimes incorrectly loading background non-restored tab.
  * Fix showing speed dials in bookmarks icon.
  * Fix showing messages in statusbar in RTL mode.
  * Fix crash when application style is externally changed.
  * Fix labels colour in access keys navigation with dark style.
  * Fix position of autoscroll indicator with site notification
    visible.
- Remove qupzilla-qt5* packages and build with Qt5 in
  openSUSE Leap 42.1 and newer.
- Instead of removing BUILDTIME, fix it up.
- Install qupzilla-gnome-keyring when gnome-keyring is installed.
- Try not to mention WebKit in description, QupZilla will move to
  QtWebEngine.
- Generate icon cache.
* Thu Oct  8 2015 javier@opensuse.org
- Update to 1.8.7
  * save pinned tabs per-window when set to restore session
  * Shift+Left click on links now opens link in new window
  * show web inspector action now toggles inspector
  * add button to create new userscript in GreaseMonkey
  * add "Anti-Adblock Killer" AdBlock subscription
  * add Ctrl+G and Ctrl+Shift+G shortcuts in search toolbar
  * fix enabling select all and find actions in menu
  * fix searching for strings with special whitespaces from locationbar
  * fix build with KF5 KWallet
  * fix crash when blocking popup window with AdBlock
  * fix icon animation when blocking popup window with AdBlock
  * fix build with Qt 5.5 and gcc 4.9
  * fix incorrectly accepting some cookies
  * fix creating new config directory
  * fix saving settings without changing pages in SpeedDial
  * fix center dials option in SpeedDial
  * fix not escaping characters for (file, ftp) dir listings
  * fix not showing restore page when opening new url from cli
  * fix adding search engine from form on page with Qt 5
  * fix saving homepage/new tab urls from preferences
  * Linux: use run-time detection of X11 platform
- Removed qupzilla-sendlink-fix.patch (merged upstream)
- Removed qupzilla-tabbar-fix.patch (merged upstream)
- Added x11extras dependency
* Thu Jun 11 2015 javier@opensuse.org
- Added qupzilla-tabbar-fix.patch
  - Fixes tabbar bug boo#934079
* Thu Mar 19 2015 javier@opensuse.org
- Added qupzilla-sendlink-fix.patch
  - Fixes send link bug gh#QupZilla/qupzilla#1625
* Wed Mar 18 2015 javier@opensuse.org
- Regenerate qupzilla-defaults.patch to actually add
  openSUSE Software and openSUSE Build Service search engines
  and load its icons as well
- Add browsedata.db for the openSUSE Project bookmark icon
* Mon Mar 16 2015 javier@opensuse.org
- Added qupzilla-defaults.patch
  * Adds an openSUSE Project link to the bookmark toolbar and
    speed dial as well
  * Adds openSUSE Software and OBS search engines
  * Hides the menu bar
- Added opensusesoftware.png and obs.png sources (favicons for
  search engines)
* Mon Jan 26 2015 sor.alexei@meowr.ru
- Update to 1.8.6:
  * added TabManager and FlashCookieManager plugins
  * added CTRL+L shortcut to clear download list in download manager
  * allow closing Download Manager and Browsing Library with Ctrl+W
  * revert option to disable SSLv3, it is now correctly handled by Qt
  * fix issue with tabs with empty url were removed from session
  * fix zoom shortcuts with +/-/0 on numeric block
  * fix hiding iframes that have completely blocked contents in AdBlock
  * fix showing navigation bar when typing into locationbar in fullscreen
  * fix visual issues with FTP listing with RTL layouts
  * fix removing profiles from preferences
  * fix crash when moving bookmarks on FreeBSD
* Sat Dec 13 2014 fisiu@opensuse.org
- Update to 1.8.5:
  * save geometry of Preferences window
  * enable HighDPI pixmaps with Qt 5
  * add option to completely disable SSLv3
  * fix url for China AdBlock list
  * fix issue with opening modal dialogs being hidden by active window
  * fix loading dictionaries in spellcheck
  * fix behavior of delete key in locationbar
  * MouseGestures: add new gesture for duplication of current tab
  * fix go-icon not available in themes other than oxygen
* Thu Nov 13 2014 hrvoje.senjan@gmail.com
- Activate KWallet support for Qt5 builds on openSUSE 13.2 and newer
- Added kwallet-devel BuildRequires for the above case
- Make KWallet plugin supplement qupzilla(-qt5) based on whether
  user has kdebase4-workspace or plasma5-workspace installed
* Sat Nov  8 2014 hrvoje.senjan@gmail.com
- Update to 1.8.4
  * added possibility to build against system QtFtp module
  * CSS exceptions in AdBlock now works for rules from different
    subscrictions
  * fixed: correctly saving some settings in preferences
  * fixed: preference action on Mac
  * fixed: loading plugins on Windows
* Mon Oct 20 2014 hrvoje.senjan@gmail.com
- Update to 1.8.3
  * fixed: crash when passing messages to running instance
  * fixed: keyboard text navigation in some custom html code
    editors
  * fixed: string for filter third party cookies + changed
    default to allow
  * fixed: coloring CSS exception rules in AdBlock
    subscription tree
  * fixed: auto-loading saved plugins on startup in
    portable mode
  * fixed: text edit shortcuts not working with non-latin
    keyboard layout
  * fixed: building on Linux with Qt 4.7
  * fixed: crash when unloading AutoScroll plugin on Windows
- Drop qupzilla-gdb-workaround.patch,
  use CONFIG-=gdb_dwarf_index directly
* Tue Oct  7 2014 sor.alexei@meowr.ru
- Update to 1.8.2 (changes since 1.6.6):
  * use bigger default font sizes
  * fixed: profile version check when updating from 1.8.0
  * reverted setting DNT header by default
  * fixed: autofill not working for some frames
  * fixed: saving speed dial in case of crash
  * added support for window.beforeunload event
  * added support for external.AddSearchProvider js function
  * added undo/redo actions to context menu in forms
  * added new theme Breathe
  * added new commandline option to toggle fullscreen
  * added new commandline option to enable portable mode
  * added new context menu action to open links in private window
  * added new smooth and fully transparent loading animation
  * added option to disable weak ciphers in SSL Manager
  * added support for shadow builds with Qt Creator
  * completely rewritten bookmarks (including multi-level folders support)
  * location bar completer is now running in separate thread
  * menus are not closed when opening links with middle mouse button
  * ctrl+w shortcut no longer closes pinned tab
  * pinned tabs are now restored everytime, not only when restoring session
  * enable sending DoNotTrack header by default
  * full support for search engines that use POST method
  * Oxygen icon theme is now default fallback icon theme
  * Qt translations are now loaded from system directories where available
  * correctly load one-word hosts (eg. localhost or anything other in /etc/hosts)
  * search engines manager can now be opened from preferences
  * various tweaks in SpeedDial theme including lower minimal size for dials
  * various tweaks in Linux theme including support for big fonts in location bar
  * various fixes for Qt5 including bugs in tab bar
  * various fixes for RTL languages including rendering of location bar completer
  * AdBlock: support for exception css rules
  * AdBlock: improved performance of loading rules
  * MouseGestures: option to set mouse button for gestures
  * MouseGestures: support for rocker navigation to go back/forward in history
  * GreaseMonkey: correctly load scripts in frames
  * GreaseMonkey: fix rare issue that userscripts won't load on some sites
  * KWalletPasswords: support for KF5 KWallet
* Wed May 14 2014 hrvoje.senjan@gmail.com
- Update to 1.6.6
  * added new AutoScroll plugin
  * added new F12 shortcut for Web Inspector
  * fixed: correctly switching between tabbars when
    closing tabs
  * fixed: draw tabbar base even when there are no tabs in
    main tabbar
  * fixed: position of add tab button when there are no tabs
    in main tabbar
  * fixed: setting correct paths for portable mode
* Sun Apr 20 2014 hrvoje.senjan@gmail.com
- Update to 1.6.5
  * fixed build issues on Mac
  * fixed error handling when downloading CA certificates bundle
  * fixed error handling when downloading AdBlock subscriptions
  * fixed loading KWalletPasswords plugin
  * Source tarballs are now compressed using xz.
- Changes since 1.6.4
  * enabled sending DoNotTrack header by default
  * updated ca-bundle certificates
  * use same session files with both Qt4 and Qt5
  * fixed: Click2Flash playing videos on YouTube with Qt5
  * fixed: hiding close button on current tab when dragging it with Qt5
  * fixed: double clicking on scroll buttons in tabbar with Qt5
  * fixed: text visibility in speeddial inputs with dark themes
  * fixed: getting tab index with rtl layout
  * fixed: ctrl+up shortcut in websearchbar correctly select first item
  * fixed: correctly loading translations of all plugins
- Use %%qmake5 macro for Qt5 build, as it exports optflags
* Fri Apr 18 2014 hrvoje.senjan@gmail.com
- BuildRequire libqt5-qttools-devel instead of just libqt5-qttools
* Thu Feb 27 2014 hrvoje.senjan@gmail.com
- Create qupzilla-qt5 package as branch to Qt4 version, and enable
  conditionals as per requirements
* Fri Feb 14 2014 javier@opensuse.org
- Update to 1.6.3
  * released 14 February 2014
  * addded new Spanish (Mexico) translation
  * option to change list of SslV3 forced sites in settings.ini
  * show error message when downloading AdBlock subscriptions fails
  * fixed building on FreeBSD, OS/2
* Thu Feb 13 2014 javier@opensuse.org
- Update to 1.6.2
  * workaround for servers not understanding TLSv1 handshake
  * tabs on top are now enabled by default
  * restore session after launch is now enabled by default
  * don't load tabs until selected is now enabled by default
  * tab previews are now disabled by default
  * reworked scrolling with wheel in tabbar
  * Ctrl+W shortcut no longer closes a pinned tab
  * fixed: setting DuckDuckGo as default search provider
  * fixed: issues detected by scan.coverity.com
  * fixed: showing more default search engines with same name
  * fixed: incorrect exception rules handling in AdBlock
  * fixed: flickering when removing tabs from tabbar
  * fixed: flickering when (un)pinning tabs
  * fixed: flickering when opening new tabs with sites that loads instantly
  * fixed: drawing correct mouseouver state for tabs
  * fixed: drawing tabbar correctly with Oxygen style
  * fixed: drawing list items with Qt5 Fusion style
  * fixed: tooltips disappearing on (un)pinning tabs
  * fixed: incorrectly changing current index when closing tabs in inactive
    tabbar
  * fixed: incorrectly showing url in locationbar when load request was not
    accepted
  * fixed: always add slash '/' between path and filename when downloading files
  * fixed: cursor jumping at the start in locationbar
  * mac: fixed toggle fullscreen action in menu
  * windows: save application data in %%LOCALAPPDATA%%
* Thu Feb 13 2014 javier@opensuse.org
-  Source field in spec file changed. The 1.6.1 tarball had to be
  recreated and this updated tarball is only available on GitHub
* Thu Feb  6 2014 javier@opensuse.org
- Update to 1.6.1
  * added option to disable inline completion in locationbar
  * added option to always switch tabs with mouse wheel
  * added option to toggle fullscreen with commandline option
  * added undo/redo context menu actions in editable web elements
  * speedup loading rules from subscriptions in AdBlock dialog
  * fixed speed dial with disabled javascript
  * fixed showing tooltips on tabs when tab previews are disabled
  * fixed search shortcuts longer than one character in locationbar
  * fixed building issues on OS X and OS/2
  * fixed disabling tab previews from preferences
  * fixed building new Gnome/KDE keyring passwords
  * fixed building StatusBarIcons plugin on Windows
  * win: add new jumplist option to open private window
- Add gdb workaround (see QTBUG-34950)
- Remove patches that have been merged into upstream
* Thu Jan  2 2014 fisiu@opensuse.org
- Build kwallet and gnome keyring plugins and put them into separate
  subpackages to minimize dependency volume.
- Added patches:
  * qupzilla-dont-show-tabs-when-disabled.patch
  * qupzilla-gnome-integration-defines-fix.patch
  * qupzilla-integration-plugins-fix.patch
  * qupzilla-reload-settings-fix.patch
* Wed Jan  1 2014 fisiu@opensuse.org
- Update to 1.6.0:
  * added support for Proxy Auto-Config (PAC)
  * added option to open another private window from private window
  * added option to detach tabs from window
  * added delete action in edit context menu on page
  * added possibility to remove EasyList from AdBlock
  * added inline domain completion to urlbar
  * added KWallet password backend plugin
  * added Gnome-Keyring password backend plugin
  * added StatusBar Icons plugin that adds extra icons to statusbar
  * added support for POST method in search engines manager
  * added context menu for translating webpage
  * added possibility to export bookmarks to html file
  * great performance improvement for matching basic rules in AdBlock
  * themes can now be loaded from profile directories
  * pagescreen can now save output into number of formats, including PDF
  * proxy exceptions now supports wildcards (*, ?)
  * cancel upload when trying to upload non-readable files
  * select previous / next engines with ctrl+up/down in websearchbar
  * ask user first before closing all but the current tab from tabbar
  * last 2 sessions are now backuped in profile directory
  * always show tab previews after a small delay
  * GreaseMonkey: added icon in statusbar
  * GreaseMonkey: added support for GM_Settings
  * GreaseMonkey: fixed userscripts when first loading plugin
  * GreaseMonkey: run userscripts in all frames on page
  * oxygen: set rounded corners for tooltips
  * oxygen: workaround for transparent background of tooltips
  * X11: Set correct WM_CLASS property to windows
  * fixed: size of preferences dialog on low-res screens
  * fixed: loading plugins with relative paths in portable build
  * fixed: displaying a lot of RSS feeds in RSS widget in locationbar
  * fixed: enabling disabled rules in AdBlock now works everytime
  * fixed: parsing OpenSearch files with XML declaration
  * fixed: don't show urls multiple times in url completer
  * fixed: drag & drop moving folders under bookmarks toolbar
  * fixed: files with relative paths can now be opened from command line
  * fixed: issues with overflowing tabs, it is now possible scroll through all tabs
* Sat Dec  7 2013 cgiboudeaux@gmx.com
- Update to 1.4.4
  * Added ctrl/shift + insert shortcuts to copy/paste in webview
  * Don't try to download empty page
  * Reverted forcing SSLv3 protocol for secured connections
  * Duckduckgo.com is now default search engine
  * Fixed: correct height of icons widget in SiteInfo
  * Fixed: hide tabbar with only one tab option now works in fullscreen
  * Fixed: crash with Oxygen theme when closing windows with tabs on top
  * Fixed: saving IgnoreAllSSLWarnings option from SSLManager
  * Fixed: crash on saving settings with unavailable theme
  * Fixed: Accept-Language header now works with all sites
  * Fixed: using external download manager with use defined location setting
  * GreaseMonkey: fixed buttons in script list with RTL layout
  * GreaseMonkey: run userscripts in all frames on page
  * X11: Set correct WM_CLASS property to windows
* Mon May 27 2013 fisiu@opensuse.org
- Update to 1.4.3 (changes since 1.4.0):
  * fixed: crash upon closing private browsing window
  * fixed: element hiding rules not working when more than 5000 in
    subscription
  * fixed: saving some tab icons in session file
  * fixed: make Acid3 test pass even with AdBlock enabled
  * don't limit speed of loading animation in tabbar
  * fixed loading HTML5 videos on YouTube
  * fixed saving cursive font in fonts preferences
  * fixed translating edit actions in page context menu
  * fixed connecting to older secured servers by forcing older SSL
    protocol
  * fixed installing bash completions to correct folder
  * fixed deleting lockfile upon closing application
  * fixed occasional crash when extracting form data from page
  * fixed crash in akn plugin while closing tab with labels shown
  * fixed crash on close when tabs on top is enabled with oxygen
    theme
  * GreaseMonkey: fixed laoding scripts with last line commented
  * fixed websearchbar not respecting select all on click settings
  * fixed certificates from custom path disappearing on saving
    preferences
  * fixed showing empty back/forward history menu upon restoring
    session
  * fixed duplicating current url in history when restoring
    session
  * fixed instantly showing popup when clicking on back/forward
    button
* Mon Mar 11 2013 dmitry_r@opensuse.org
- Update to version 1.4.0
  * highlighting host in address in locationbar
  * can now be compiled using Qt 5
  * QtWebKit 2.3 new features - caret browsing, animated scrolling
  * added support for FTP listing files and downloading
  * added support for saving passwords of multiple users per site
  * added support for showing tabs on top
  * added bash autocompletion file
  * added more actions to super menu, also show menu inside window
  * possibility to select text on page with Shift+Arrow keys
  * asking user whether to allow site to use notifications/geolocation
  * option to set JavaScript privacy permissions
  * use .qupzilla/tmp instead of /tmp for temporary data
  * saving passwords should now work for much more sites
  * improved showing navigation toolbar in fullscreen
  * moved config directory into ~/.config/qupzilla
  * certificates bundle is now only used on windows
  * reduced memory usage of AdBlock (saves up to 30MB with just EasyList)
  * greatly improved performance when matching regexp rules in AdBlock
  * GreaseMonkey: reload script if source file changed on disk
  * GreaseMonkey: fixed don't loading invalid scripts
* Wed Sep 19 2012 freitag@opensuse.org
- Update to 1.3.5:
  * released 16 September 2012
  * new Persion translation
  * option to remove web search bar
  * warning user when removing page from speed dial
  * option to align pages to center in speed dial
  * added shortcut for Clear private data
  * new options in AdBlock menu to disable it for domain and for single page
  * added option to disable search suggestions in search bar
  * added option to choose what to suggest in address bar
  * Save x as ... actions will always show file dialog
  * possibility to choose to use external download manager on every download
  * remember last section in preferences
  * much more tabs now fits into tabbar without overflowing into tab buttons
  * smarter address bar completer will show better search results
  * support for bookmarks manager and sidebar drag&drop managing bookmarks
  * new User Agent manager lets you set User Agent per site
  * new restore session page lets you choose which tabs you want to restore
  * new scheme handler for file protocol allows browsing through directories
  * new option to show loading progress in address bar
  * new option to hide close button on tabs
  * new option to start new instance with --no-remote option
  * X11: restore windows on correct virtual desktops
  * MouseGestures: added 2 new gestures for switching tabs
  * fixed visibility of navigation bar in fullscreen
  * fixed bad position of add tab button when there is a lot of tabs
  * fixed gui with RTL languages
  * fixed issue with infinite opening mailto links
  * fixed issue with showing warning after creating new profile
  * fixed clearing highlight when search text not found
  * fixed closing bookmarks menu when menu toolbar is hidden
  * fixed occasional crashes when closing tab while it is still loading
* Mon Jul 16 2012 dmitry_r@opensuse.org
- Update to 1.3.1:
  * Ctrl+= shortcut for + zoom in webview
  * Ctrl+Enter shortcut in PIM plugin now also works with enter on numpad
  * don't append QupZilla string to changed user agent
  * fixed ' and " chars in speed dial's input fields
  * fixed zooming with Ctrl+Wheel for some users
  * fixed issues with cookies filtering
  * fixed $subdocument matching in AdBlock
  * fixed $third-party in AdBlock rules when Referer header is empty
  * fixed issue with notifications settings always reverting to osd notifications
  * fixed downloading UTF-8 subscriptions in AdBlock (eg. Ru Adlist)
* Thu Jul 12 2012 dmitry_r@opensuse.org
- Update to 1.3.0:
  + new Ukrainian translations
  + new plugins: GreaseMonkey and PIM (Personal Information Manager)
  + new command line option to open new window with url
  + can now open .xhtml files from open file dialog
  + added animated tab previews with option to turn animations off
  + ssl manager now can import own certificate
  + new urlbar completion widget can now show also entries from bookmarks
  + support for 3rd party subscriptions in AdBlock
  + private browsing is now opened in new window and new process
  + possibility to add RSS feed into external reader
* Thu Apr  5 2012 fisiu@opensuse.org
- Update to 1.2.0:
  + Plugin support: MouseGestures and AccessKeysNavigation.
  + Restoring session opens selected tabs as first.
  + New translations: Brazilian Portuguese, Indonesian,
    Georgian, Japanese and Romanian.
  + Import bookmarks from html.
  + White/Black-listing cookies.
  + Many bugfixes and minor changes.
- Use USE_LIBPATH=%%{_libdir} to build properly for x86_64.
* Tue Feb 14 2012 fisiu@opensuse.org
- Update to 1.1.8:
  + new translations: Swedish, Serbian and Traditional Chinese
  + option to use external download manager
  + import/export passwords into xml file
  + option to change user agent
  + support for JavaScript Popup windows
  + allow changing background in Speed Dial
  + many bugfixes, details in Changelog file
- Drop qupzilla-1.1.5-remove-date-time.patch: sed'ed in .spec
* Sat Jan  7 2012 fisiu@opensuse.org
- Update to 1.1.5:
  + new translations: Portuguese, French, Greek
  + add support for js printing with window.print()
  + improved commandline options
  + improved performance of history delete
  + many bugfixes
- Rebase remove_date-time.patch
* Mon Dec 19 2011 fisiu@opensuse.org
- Upstream update to 1.1.0:
  + speed dial
  + import bookmarks from html file
  + option to turn on XSS Auditing
  + many bugfixes
- Set variable KDE to "true" to enable better integration
  (atm only incons, nepomuk is planned)
* Tue Nov  1 2011 fisiu@opensuse.org
- enable webgl only for openSUSE >= 12.1
* Tue Nov  1 2011 fisiu@opensuse.org
- initial package
